@@ -6,20 +6,59 @@ OS = os
 SYS = sys
 OS_SEPARATOR = OS.path.sep
 
-LINUX_OS_NAME = 'linux'
-WINDOWS_OS_NAME = 'win32'
+# ┍━━━━━━━━━━━━━━━━━━━━━┯━━━━━━━━━━━━━━━━━━━━━┑
+# │ System              │ Value               │
+# ┝━━━━━━━━━━━━━━━━━━━━━┿━━━━━━━━━━━━━━━━━━━━━┥
+# │ Linux               │ linux or linux2 (*) │
+# │ Windows             │ win32               │
+# │ Windows/Cygwin      │ cygwin              │
+# │ Windows/MSYS2       │ msys                │
+# │ Mac OS X            │ darwin              │
+# │ OS/2                │ os2                 │
+# │ OS/2 EMX            │ os2emx              │
+# │ RiscOS              │ riscos              │
+# │ AtheOS              │ atheos              │
+# │ FreeBSD 7           │ freebsd7            │
+# │ FreeBSD 8           │ freebsd8            │
+# │ FreeBSD N           │ freebsdN            │
+# │ OpenBSD 6           │ openbsd6            │
+# ┕━━━━━━━━━━━━━━━━━━━━━┷━━━━━━━━━━━━━━━━━━━━━┙
+
+LINUX_OS_NAME_LIST = [
+    'linux',
+    'linux2'
+]
+WINDOWS_OS_NAME_LIST = [
+    'win32',
+    'win64',
+    'cygwin',
+    'msys'
+]
+MAC_OS_NAME_LIST = [
+    'darwin'
+]
+OTHER_OS_NAME_LIST = [
+    'os2',
+    'os2emx',
+    'riscos',
+    'atheos',
+    'freebsd7',
+    'freebsd8',
+    'freebsdN',
+    'openbsd6'
+]
 
 clear = lambda: OS.system('cls')
 
 def setMaxIntToStringDigits(number):
     SYS.set_int_max_str_digits(4300)
 
-def get(environmentKey, default=None) :
+def get(environmentKey, default=None):
     environmentValue = default if ObjectHelper.isNone(environmentKey) else OS.environ.get(environmentKey)
     return environmentValue if ObjectHelper.isNotNone(environmentValue) else default
 
-def update(environmentKey, environmentValue, default=None) :
-    if ObjectHelper.isNotEmpty(environmentKey) :
+def update(environmentKey, environmentValue, default=None):
+    if ObjectHelper.isNotEmpty(environmentKey):
         associatedValue = None
         if ObjectHelper.isNotNone(environmentValue):
             associatedValue = str(StringHelper.filterString(environmentValue))
@@ -37,22 +76,22 @@ def update(environmentKey, environmentValue, default=None) :
         LogHelper.debug(update, f'arguments: environmentKey: {environmentKey}, environmentValue: {environmentValue}, default: {default}')
         raise Exception(f'Error associating environment variable "{environmentKey}" key to environment variable "{environmentValue}" value')
 
-def switch(environmentKey, environmentValue, default=None) :
+def switch(environmentKey, environmentValue, default=None):
     originalEnvironmentValue = get(environmentKey, default=default)
     update(environmentKey, environmentValue, default=default)
     return originalEnvironmentValue
 
-def reset(environmentVariables, originalEnvironmentVariables) :
+def reset(environmentVariables, originalEnvironmentVariables):
     if environmentVariables :
-        for key in environmentVariables.keys() :
+        for key in environmentVariables.keys():
             if key in originalEnvironmentVariables :
                 update(key, originalEnvironmentVariables[key])
 
-def delete(environmentKey) :
-    if ObjectHelper.isNotNone(environmentKey) :
+def delete(environmentKey):
+    if ObjectHelper.isNotNone(environmentKey):
         OS.environ.pop(environmentKey)
 
-def getSet(avoidRecursiveCall=False) :
+def getSet(avoidRecursiveCall=False):
     try :
         return {key : OS.environ[key] for key in OS.environ}
     except Exception as exception :
@@ -60,28 +99,28 @@ def getSet(avoidRecursiveCall=False) :
         return str(OS.environ)[8:-1]
 
 def isNone(environmentKey, default=True, evaluateItInsted=None):
-    if ObjectHelper.isNotNone(environmentKey) :
+    if ObjectHelper.isNotNone(environmentKey):
         return c.NONE == (
             evaluateItInsted if ObjectHelper.isNotNone(evaluateItInsted) else get(environmentKey, default=c.NONE)
         )
     return default
 
 def isNotNone(environmentKey, default=True, evaluateItInsted=None):
-    if ObjectHelper.isNotNone(environmentKey) :
+    if ObjectHelper.isNotNone(environmentKey):
         return not c.NONE == (
             evaluateItInsted if ObjectHelper.isNotNone(evaluateItInsted) else get(environmentKey, default=c.NONE)
         )
     return default
 
 def isBoolean(environmentKey, default=False, evaluateItInsted=None):
-    if ObjectHelper.isNotNone(environmentKey) :
+    if ObjectHelper.isNotNone(environmentKey):
         if ObjectHelper.isNotNone(evaluateItInsted):
             return evaluateItInsted in [c.TRUE, c.FALSE] if isNotNone(environmentKey, evaluateItInsted=evaluateItInsted) else default
         return get(environmentKey, default=default) in [c.TRUE, c.FALSE]
     return default
 
 def isTrue(environmentKey, default=False, evaluateItInsted=None):
-    if ObjectHelper.isNotNone(environmentKey) :
+    if ObjectHelper.isNotNone(environmentKey):
         if ObjectHelper.isNotNone(evaluateItInsted):
             return c.TRUE == evaluateItInsted if isBoolean(environmentKey, default=default, evaluateItInsted=evaluateItInsted) else default
         innerEvaluatItInsted = get(environmentKey, default=None)
@@ -92,7 +131,7 @@ def isTrue(environmentKey, default=False, evaluateItInsted=None):
     return default
 
 def isFalse(environmentKey, default=True, evaluateItInsted=None):
-    if ObjectHelper.isNotNone(environmentKey) :
+    if ObjectHelper.isNotNone(environmentKey):
         if ObjectHelper.isNotNone(evaluateItInsted):
             return c.FALSE == evaluateItInsted if isBoolean(environmentKey, default=default, evaluateItInsted=evaluateItInsted) else default
         innerEvaluatItInsted = get(environmentKey, default=None)
@@ -102,28 +141,28 @@ def isFalse(environmentKey, default=True, evaluateItInsted=None):
             return c.FALSE == c.FALSE if isinstance(default, bool) and not default else c.TRUE
     return default
 
-def listDirectoryContent(path) :
+def listDirectoryContent(path):
     return OS.listdir(path)
 
-def isDirectory(path) :
+def isDirectory(path):
     return OS.path.isdir(path)
 
-def isFile(path) :
+def isFile(path):
     return OS.path.isfile(path)
 
-def makeDirectory(path, accessRights=0o777) :
+def makeDirectory(path, accessRights=0o777):
     ###- accessRights = 0o777 --> write, access and read
     ###- accessRights = 0o755 --> access and read
     ###- accessRights = 0o755 --> access and read
     OS.makedirs(path, mode=accessRights)
 
-def appendPath(path) :
+def appendPath(path):
     SYS.path.append(path)
 
-def getCurrentSoutStatus(avoidRecursiveCall=False) :
+def getCurrentSoutStatus(avoidRecursiveCall=False):
     return SYS.stdout, SYS.stderr
 
-def overrideSoutStatus(stdout, stderr) :
+def overrideSoutStatus(stdout, stderr):
     SYS.stdout = stdout
     SYS.stderr = stderr
 
@@ -138,8 +177,14 @@ def flushIO():
         except Exception as e:
             print(f'------------- EnvironmentHelper.flushIO exception: {e} -------------')
 
-def isLinux() :
-    return SYS.platform == LINUX_OS_NAME
+def isLinux():
+    return SYS.platform in LINUX_OS_NAME_LIST
 
-def isWindows() :
-    return SYS.platform == WINDOWS_OS_NAME
+def isWindows():
+    return SYS.platform in WINDOWS_OS_NAME_LIST
+
+def isMacOs():
+    return SYS.platform in MAC_OS_NAME_LIST
+
+def isOtherOs():
+    return SYS.platform in OTHER_OS_NAME_LIST
